==> azureml_train_automl_runtime-1.0.76.1-py3-none-any.whl: azureml/train/automl/runtime/run.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""
The automated machine learning Run class.

Provides methods for starting/stopping runs, monitoring run status, and retrieving model output.
"""
from typing import Dict
import json
import numpy as np
import pandas as pd
from azureml.automl.runtime.data_context import TransformedDataContext
from azureml._restclient.constants import RunStatus
from azureml.train.automl.run import AutoMLRun as _AutoMLRun
from azureml.train.automl import _azureautomlclient, _constants_azureml, _logging, constants
from azureml.train.automl._azureautomlsettings import AzureAutoMLSettings

# Task: 287629 Remove when Mix-in available
STATUS = 'status'

RUNNING_STATES = [RunStatus.STARTING, RunStatus.PREPARING, RunStatus.RUNNING,
                  RunStatus.PROVISIONING, RunStatus.QUEUED]
POST_PROCESSING_STATES = [RunStatus.FINALIZING, RunStatus.CANCEL_REQUESTED]

CONTINUE_EXPERIMENT_KEY = 'continue'
CONTINUE_EXPERIMENT_SET = 'Set'
CONTINUE_EXPERIMENT_STATUS_KEY = '_aml_system_automl_status'


class AutoMLRun(_AutoMLRun):
    """
    AutoMLRun has information of the experiment runs that correspond to the AutoML run.

    This class can be used to manage, check status, and retrieve run details
    once a AutoML run is submitted.

    :param experiment: The experiment associated to the run.
    :type experiement: azureml.core.Experiment
    :param run_id: The id associated to the run.
    :type run_id: str
    """

    def clean_preprocessor_cache(self):
        """Clean the transformed, preprocessed data cache."""
        try:
            from azureml.train.automl.runtime._cachestorefactory import CacheStoreFactory
            properties = self.get_properties()
            cache_path = None

            if 'AMLSettingsJsonString' not in properties:
                compute_target = constants.ComputeTargets.LOCAL
            else:
                automl_settings = AzureAutoMLSettings(
                    experiment=self.experiment,
                    **json.loads(properties['AMLSettingsJsonString']))
                compute_target = automl_settings.compute_target

            # TODO: Can we have a cleaner way of doing this?
            cache_store = CacheStoreFactory.get_cache_store(
                enable_cache=True,
                run_target=compute_target,
                run_id=self.run_id,
                data_store=self.experiment.workspace.get_default_datastore(),
                temp_location=cache_path)
            transformed_data_context = TransformedDataContext(
                X={},
                cache_store=cache_store)
            transformed_data_context.cleanup()
        except Exception:
            pass

==> azureml_train_automl_runtime-1.0.85.1-py3-none-any.whl: azureml/train/automl/runtime/run.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""
The automated machine learning Run class.

Provides methods for starting/stopping runs, monitoring run status, and retrieving model output.
"""
from typing import Dict
import json
import numpy as np
import pandas as pd
from azureml.automl.runtime.data_context import TransformedDataContext
from azureml._restclient.constants import RunStatus
from azureml.train.automl.run import AutoMLRun as _AutoMLRun
from azureml.train.automl import _azureautomlclient, _constants_azureml, _logging, constants
from azureml.train.automl._azureautomlsettings import AzureAutoMLSettings

# Task: 287629 Remove when Mix-in available
STATUS = 'status'

RUNNING_STATES = [RunStatus.STARTING, RunStatus.PREPARING, RunStatus.RUNNING,
                  RunStatus.PROVISIONING, RunStatus.QUEUED]
POST_PROCESSING_STATES = [RunStatus.FINALIZING, RunStatus.CANCEL_REQUESTED]

CONTINUE_EXPERIMENT_KEY = 'continue'
CONTINUE_EXPERIMENT_SET = 'Set'
CONTINUE_EXPERIMENT_STATUS_KEY = '_aml_system_automl_status'


class AutoMLRun(_AutoMLRun):
    """
    AutoMLRun has information of the experiment runs that correspond to the AutoML run.

    This class can be used to manage, check status, and retrieve run details
    once a AutoML run is submitted.

    :param experiment: The experiment associated to the run.
    :type experiement: azureml.core.Experiment
    :param run_id: The id associated to the run.
    :type run_id: str
    """

    def clean_preprocessor_cache(self):
        """Clean the transformed, preprocessed data cache."""
        try:
            from azureml.train.automl.runtime._cachestorefactory import CacheStoreFactory
            properties = self.get_properties()
            cache_path = None

            if 'AMLSettingsJsonString' not in properties:
                compute_target = constants.ComputeTargets.LOCAL
            else:
                automl_settings = AzureAutoMLSettings(
                    experiment=self.experiment,
                    **json.loads(properties['AMLSettingsJsonString']))
                compute_target = automl_settings.compute_target

            # TODO: Can we have a cleaner way of doing this?
            cache_store = CacheStoreFactory.get_cache_store(
                enable_cache=True,
                temp_location=cache_path,
                run_target=compute_target,
                run_id=self.run_id,
                data_store=self.experiment.workspace.get_default_datastore())
            transformed_data_context = TransformedDataContext(
                X={},
                cache_store=cache_store)
            transformed_data_context.cleanup()
        except Exception:
            pass
